"""This module provides a dictionary of rgb values with keys of color names."""

color_table = """Aero	#7CB9E8	49%	73%	91%	206°	70%	70%	47%	91%
Aero blue	#C9FFE5	79%	100%	90%	151°	100%	89%	21%	100%
African violet	#B284BE	70%	52%	75%	288°	31%	63%	31%	75%
Air Force blue (RAF)	#5D8AA8	36%	54%	66%	204°	30%	51%	45%	66%
Air Force blue (USAF)	#00308F	0%	19%	56%	220°	100%	28%	100%	56%
Air superiority blue	#72A0C1	45%	63%	76%	205°	39%	60%	41%	76%
Alabama Crimson	#A32638	64%	15%	22%	350°	62%	39%	80%	60%
Alice blue	#F0F8FF	94%	97%	100%	208°	100%	97%	6%	100%
Alizarin crimson	#E32636	89%	15%	21%	355°	77%	52%	83%	89%
Alloy orange	#C46210	77%	38%	6%	27°	85%	42%	92%	77%
Almond	#EFDECD	94%	87%	80%	30°	52%	87%	14%	94%
Amaranth	#E52B50	90%	17%	31%	348°	78%	53%	81%	90%
Amazon	#3B7A57	23%	48%	34%	147°	35%	36%	52%	48%
Amber	#FFBF00	100%	75%	0%	45°	100%	50%	100%	100%
SAE/ECE Amber (color)	#FF7E00	100%	49%	0%	30°	100%	50%	100%	100%
American rose	#FF033E	100%	1%	24%	345°	100%	51%	99%	87%
Amethyst	#9966CC	60%	40%	80%	270°	50%	60%	50%	80%
Android green	#A4C639	64%	78%	22%	74°	55%	50%	71%	78%
Anti-flash white	#F2F3F4	95%	95%	96%	210°	8%	95%	1%	96%
Antique brass	#CD9575	80%	58%	46%	22°	47%	63%	43%	80%
Antique bronze	#665D1E	40%	36%	12%	53°	55%	26%	71%	40%
Antique fuchsia	#915C83	57%	36%	51%	316°	22%	47%	37%	57%
Antique ruby	#841B2D	52%	11%	18%	350°	66%	31%	80%	52%
Antique white	#FAEBD7	98%	92%	84%	34°	78%	91%	14%	98%
Ao (English)	#008000	0%	50%	0%	120°	100%	25%	100%	50%
Apple green	#8DB600	55%	71%	0%	74°	100%	36%	100%	71%
Apricot	#FBCEB1	98%	81%	69%	24°	90%	84%	29%	98%
Aqua	#00FFFF	0%	100%	100%	160°	100%	50%	100%	100%
Aquamarine	#7FFFD4	50%	100%	83%	160°	100%	75%	50%	100%
Army green	#4B5320	29%	33%	13%	69°	44%	23%	61%	33%
Arsenic	#3B444B	23%	27%	29%	206°	12%	26%	21%	29%
Arylide yellow	#E9D66B	91%	84%	42%	51°	74%	67%	54%	91%
Ash grey	#B2BEB5	70%	75%	71%	135°	9%	72%	6%	75%
Asparagus	#87A96B	53%	66%	42%	93°	27%	54%	37%	66%
Atomic tangerine	#FF9966	100%	60%	40%	20°	100%	70%	60%	100%
Auburn	#A52A2A	65%	16%	16%	0°	59%	41%	74%	64%
Aureolin	#FDEE00	99%	93%	0%	56°	100%	50%	100%	99%
AuroMetalSaurus	#6E7F80	43%	50%	50%	183°	8%	47%	14%	50%
Avocado	#568203	34%	51%	1%	81°	96%	26%	98%	51%
Azure	#007FFF	0%	50%	100%	210°	100%	50%	100%	100%
Azure mist/web	#F0FFFF	94%	100%	100%	180°	100%	97%	6%	100%
Baby blue	#89CFF0	54%	81%	94%	199°	77%	74%	43%	94%
Baby blue eyes	#A1CAF1	63%	79%	95%	209°	74%	79%	33%	95%
Baby pink	#F4C2C2	96%	76%	76%	30°	69%	86%	21%	96%
Baby powder	#FEFEFA	100%	100%	98%	60°	67%	99%	2%	100%
Baker-Miller pink	#FF91AF	100%	57%	69%	344°	100%	78%	43%	100%
Ball blue	#21ABCD	13%	67%	80%	192°	72%	47%	84%	80%
Banana Mania	#FAE7B5	98%	91%	71%	43°	87%	85%	28%	98%
Banana yellow	#FFE135	100%	88%	21%	51°	100%	60%	79%	100%
Barbie pink	#E0218A	88%	13%	54%	327°	76%	50%	85%	88%
Barn red	#7C0A02	49%	4%	1%	4°	97%	25%	98%	49%
Battleship grey	#848482	52%	52%	51%	60°	1%	51%	2%	52%
Bazaar	#98777B	60%	47%	48%	353°	14%	53%	22%	60%
Beau blue	#BCD4E6	74%	83%	90%	206°	46%	82%	18%	90%
Beaver	#9F8170	62%	51%	44%	22°	20%	53%	35%	63%
Beige	#F5F5DC	96%	96%	86%	60°	56%	91%	10%	96%
B'dazzled Blue	#2E5894	18%	35%	58%	215°	53%	38%	69%	58%
Big dip o’ruby	#9C2542	61%	15%	26%	345°	62%	38%	76%	61%
Bisque	#FFE4C4	100%	89%	77%	33°	100%	88%	23%	100%
Bistre	#3D2B1F	24%	17%	12%	24°	33%	18%	49%	24%
Bistre brown	#967117	59%	44%	9%	43°	73%	34%	85%	59%
Bitter lemon	#CAE00D	79%	88%	5%	66°	89%	47%	94%	88%
Bitter lime	#BFFF00	39%	55%	7%	79°	78%	31%	78%	84%
Bittersweet	#FE6F5E	100%	44%	37%	6°	99%	68%	63%	100%
Bittersweet shimmer	#BF4F51	75%	31%	32%	359°	47%	53%	59%	75%
Black	#000000	0%	0%	0%	—	0%	0%	0%	0%
Black bean	#3D0C02	24%	5%	1%	10°	94%	12%	97%	24%
Black leather jacket	#253529	15%	21%	16%	135°	18%	18%	6%	18%
Black olive	#3B3C36	23%	24%	21%	70°	5%	22%	10%	24%
Blanched almond	#FFEBCD	100%	92%	80%	36°	100%	90%	20%	100%
Blast-off bronze	#A57164	65%	44%	39%	12°	27%	52%	39%	65%
Bleu de France	#318CE7	19%	55%	91%	210°	79%	55%	79%	91%
Blizzard Blue	#ACE5EE	67%	90%	93%	188°	66%	80%	28%	93%
Blond	#FAF0BE	98%	94%	75%	50°	86%	86%	24%	98%
Blue	#0000FF	0%	0%	100%	240°	100%	50%	100%	100%
Blue (Crayola)	#1F75FE	12%	46%	100%	213°	99%	56%	99%	100%
Blue (Munsell)	#0093AF	0%	58%	69%	190°	100%	34%	100%	68%
Blue (NCS)	#0087BD	0%	53%	74%	197°	100%	37%	100%	74%
Blue (pigment)	#333399	20%	20%	60%	240°	50%	40%	67%	60%
Blue (RYB)	#0247FE	1%	28%	100%	224°	99%	50%	99%	99%
Blue Bell	#A2A2D0	64%	64%	82%	240°	33%	73%	22%	81%
Blue-gray	#6699CC	40%	60%	80%	210°	50%	60%	50%	80%
Blue-green	#0D98BA	5%	60%	73%	192°	87%	39%	93%	73%
Blue sapphire	#126180	7%	38%	50%	197°	75%	29%	86%	50%
Blue-violet	#8A2BE2	54%	17%	89%	266°	76%	53%	81%	89%
Blue yonder	#5072A7	31%	45%	65%	217°	35%	48%	52%	66%
Blueberry	#4F86F7	31%	53%	97%	220°	91%	64%	68%	97%
Bluebonnet	#1C1CF0	11%	11%	94%	240°	88%	53%	83%	94%
Blush	#DE5D83	87%	36%	51%	342°	66%	62%	58%	87%
Bole	#79443B	47%	27%	23%	30°	34%	35%	24%	34%
Bondi blue	#0095B6	0%	58%	71%	191°	100%	36%	100%	71%
Bone	#E3DAC9	89%	85%	79%	48°	32%	84%	30%	95%
Boston University Red	#CC0000	80%	0%	0%	0°	100%	40%	100%	80%
Bottle green	#006A4E	0%	42%	31%	164°	100%	21%	100%	41%
Boysenberry	#873260	53%	20%	38%	328°	46%	36%	63%	53%
Brandeis blue	#0070FF	0%	44%	100%	214°	100%	50%	100%	100%
Brass	#B5A642	71%	65%	26%	52°	47%	48%	64%	71%
Brick red	#CB4154	80%	25%	33%	352°	57%	53%	68%	80%
Bright cerulean	#1DACD6	11%	67%	84%	194°	76%	48%	86%	84%
Bright green	#66FF00	40%	100%	0%	96°	100%	50%	100%	100%
Bright lavender	#BF94E4	75%	58%	89%	272°	60%	74%	35%	89%
Bright maroon	#C32148	76%	13%	28%	345°	71%	45%	75%	38%
Bright pink	#FF007F	100%	0%	50%	330°	100%	50%	100%	100%
Bright turquoise	#08E8DE	3%	91%	87%	177°	93%	47%	97%	91%
Bright ube	#D19FE8	82%	62%	91%	281°	61%	77%	31%	91%
Brilliant lavender	#F4BBFF	96%	73%	100%	290°	100%	87%	27%	100%
Brilliant rose	#FF55A3	100%	33%	64%	332°	100%	67%	67%	100%
Brink pink	#FB607F	98%	38%	50%	348°	95%	68%	62%	98%
British racing green	#004225	0%	26%	15%	154°	100%	13%	100%	26%
Bronze	#CD7F32	80%	50%	20%	30°	61%	50%	76%	80%
Bronze Yellow	#737000	45%	44%	0%	58°	100%	23%	100%	45%
Brown (traditional)	#964B00	59%	29%	0%	30°	100%	29%	100%	59%
Brown (web)	#A52A2A	65%	16%	16%	0°	59%	41%	75%	65%
Brown-nose	#6B4423	40%	27%	14%	28°	49%	27%	67%	42%
Brunswick green	#1B4D3E	11%	30%	24%	162°	48%	20%	65%	30%
Bubble gum	#FFC1CC	100%	76%	80%	349°	100%	88%	23%	99%
Bubbles	#E7FEFF	91%	100%	100%	183°	100%	95%	9%	100%
Buff	#F0DC82	94%	86%	51%	49°	79%	73%	46%	94%
Bulgarian rose	#480607	28%	2%	3%	359°	85%	15%	92%	28%
Burgundy	#800020	50%	0%	13%	345°	100%	25%	100%	50%
Burlywood	#DEB887	87%	72%	53%	34°	57%	70%	39%	87%
Burnt orange	#CC5500	80%	33%	0%	25°	100%	40%	100%	80%
Burnt sienna	#E97451	91%	45%	32%	14°	78%	62%	65%	91%
Burnt umber	#8A3324	54%	20%	14%	9°	59%	34%	74%	54%
Byzantine	#BD33A4	74%	20%	64%	311°	58%	47%	73%	74%
Byzantium	#702963	44%	16%	39%	311°	46%	30%	63%	44%
Cadet	#536872	33%	41%	45%	206°	16%	39%	31%	47%
Cadet blue	#5F9EA0	37%	62%	63%	182°	26%	50%	41%	63%
Cadet grey	#91A3B0	57%	64%	69%	205°	16%	63%	18%	69%
Cadmium green	#006B3C	0%	42%	24%	154°	100%	21%	100%	42%
Cadmium orange	#ED872D	93%	53%	18%	28°	84%	55%	81%	93%
Cadmium red	#E30022	89%	0%	13%	351°	100%	45%	100%	89%
Cadmium yellow	#FFF600	100%	96%	0%	34°	100%	50%	93%	100%
Café au lait	#A67B5B	65%	48%	36%	26°	30%	50%	45%	65%
Café noir	#4B3621	29%	21%	13%	30°	39%	21%	56%	29%
Cal Poly green	#1E4D2B	12%	30%	17%	137°	44%	21%	61%	30%
Cambridge Blue	#A3C1AD	64%	76%	68%	140°	20%	70%	16%	76%
Camel	#C19A6B	76%	60%	42%	33°	41%	59%	45%	76%
Cameo pink	#EFBBCC	94%	73%	80%	340°	62%	84%	22%	94%
Camouflage green	#78866B	47%	53%	42%	91°	11%	47%	20%	53%
Canary yellow	#FFEF00	100%	94%	0%	56°	100%	50%	100%	100%
Candy apple red	#FF0800	100%	3%	0%	2°	100%	50%	100%	100%
Candy pink	#E4717A	89%	44%	48%	355°	68%	67%	50%	89%
Capri	#00BFFF	0%	75%	100%	195°	100%	50%	100%	100%
Caput mortuum	#592720	35%	15%	13%	7°	47%	24%	64%	35%
Cardinal	#C41E3A	77%	12%	23%	350°	74%	44%	85%	77%
Caribbean green	#00CC99	0%	80%	60%	150°	100%	40%	100%	44%
Carmine	#960018	59%	0%	9%	350°	100%	29%	100%	59%
Carmine (M&P)	#D70040	84%	0%	25%	342°	100%	42%	100%	84%
Carmine pink	#EB4C42	92%	30%	26%	4°	81%	59%	72%	92%
Carmine red	#FF0038	100%	0%	22%	347°	100%	50%	100%	100%
Carnation pink	#FFA6C9	100%	65%	79%	336°	100%	83%	35%	100%
Carnelian	#B31B1B	70%	11%	11%	0°	74%	40%	85%	70%
Carolina blue	#99BADD	60%	73%	87%	211°	50%	73%	31%	87%
Carrot orange	#ED9121	93%	57%	13%	33°	85%	53%	86%	93%
Castleton green	#00563F	0%	34%	25%	164°	100%	17%	100%	34%
Catalina blue	#062A78	2%	16%	47%	221°	91%	25%	95%	47%
Catawba	#703642	44%	21%	26%	348°	35%	33%	52%	44%
Cedar Chest	#C95A49	79%	35%	29%	8°	54%	54%	64%	79%
Ceil	#92A1CF	57%	63%	81%	225°	39%	69%	30%	81%
Celadon	#ACE1AF	67%	88%	69%	174°	47%	78%	47%	73%
Celadon blue	#007BA7	0%	48%	65%	196°	100%	33%	100%	65%
Celadon green	#2F847C	18%	52%	49%	123°	48%	35%	24%	88%
Celeste (colour)	#B2FFFF	70%	100%	100%	180°	100%	85%	30%	100%
Celestial blue	#4997D0	29%	59%	82%	205°	59%	55%	65%	81%
Cerise	#DE3163	87%	19%	39%	343°	72%	53%	78%	87%
Cerise pink	#EC3B83	93%	23%	51%	336°	82%	58%	75%	93%
Cerulean	#007BA7	0%	48%	65%	196°	100%	33%	100%	65%
Cerulean blue	#2A52BE	16%	32%	75%	224°	64%	46%	78%	75%
Cerulean frost	#6D9BC3	43%	61%	76%	208°	42%	60%	44%	77%
CG Blue	#007AA5	0%	48%	65%	196°	100%	32%	100%	65%
CG Red	#E03C31	88%	24%	19%	4°	74%	54%	78%	88%
Chamoisee	#A0785A	63%	47%	35%	26°	28%	49%	44%	63%
Champagne	#F7E7CE	97%	91%	81%	37°	72%	89%	17%	97%
Charcoal	#36454F	21%	27%	31%	204°	19%	26%	31%	31%
Charleston green	#232B2B	14%	17%	17%	180°	10%	15%	19%	17%
Charm pink	#E68FAC	90%	56%	67%	333°	64%	73%	50%	87%
Chartreuse (traditional)	#DFFF00	87%	100%	0%	68°	100%	50%	100%	100%
Chartreuse (web)	#7FFF00	50%	100%	0%	90°	100%	50%	100%	100%
Cherry	#DE3163	87%	19%	39%	343°	72%	53%	78%	87%
Cherry blossom pink	#FFB7C5	100%	72%	77%	348°	100%	86%	28%	100%
Chestnut	#954535	56%	27%	21%	10°	46%	39%	54%	68%
China pink	#DE6FA1	87%	44%	63%	333°	63%	65%	50%	87%
China rose	#A8516E	66%	32%	43%	340°	35%	49%	52%	66%
Chinese red	#AA381E	67%	22%	12%	11°	70%	39%	82%	67%
Chinese violet	#856088	52%	38%	53%	296°	17%	46%	29%	53%
Chocolate (traditional)	#7B3F00	48%	25%	0%	31°	100%	24%	100%	48%
Chocolate (web)	#D2691E	82%	41%	12%	25°	75%	47%	86%	82%
Chrome yellow	#FFA700	100%	65%	0%	40°	100%	50%	100%	100%
Cinereous	#98817B	60%	51%	48%	12°	12%	54%	19%	60%
Cinnabar	#E34234	89%	26%	20%	5°	76%	55%	77%	89%
Cinnamon	#D2691E	82%	41%	12%	25°	75%	47%	86%	82%
Citrine	#E4D00A	89%	82%	4%	54°	92%	47%	96%	89%
Citron	#9FA91F	62%	66%	12%	64°	69%	39%	82%	66%
Claret	#7F1734	50%	9%	20%	343°	69%	29%	82%	50%
Classic rose	#FBCCE7	98%	80%	91%	333°	86%	89%	100%	20%
Cobalt	#0047AB	0%	28%	67%	215°	100%	34%	100%	67%
Cocoa brown	#D2691E	82%	41%	12%	25°	75%	47%	86%	82%
Coconut	#965A3E	59%	35%	24%	19°	42%	42%	59%	59%
Coffee	#6F4E37	44%	31%	22%	25°	34%	33%	51%	44%
Columbia blue	#9BDDFF	61%	87%	100%	200°	100%	80%	39%	100%
Congo pink	#F88379	97%	51%	47%	5°	90%	72%	51%	97%
Cool black	#002E63	0%	18%	39%	212°	100%	19%	100%	39%
Cool grey	#8C92AC	55%	57%	67%	229°	16%	61%	19%	68%
Copper	#B87333	72%	45%	20%	29°	57%	46%	72%	72%
Copper (Crayola)	#DA8A67	85%	54%	40%	18°	61%	63%	53%	85%
Copper penny	#AD6F69	68%	44%	41%	5°	29%	55%	39%	68%
Copper red	#CB6D51	80%	43%	32%	14°	54%	56%	60%	80%
Copper rose	#996666	60%	40%	40%	0°	20%	50%	33%	60%
Coquelicot	#FF3800	100%	22%	0%	13°	100%	50%	100%	100%
Coral	#FF7F50	100%	50%	31%	16°	100%	66%	69%	100%
Coral pink	#F88379	97%	51%	47%	5°	90%	72%	51%	97%
Coral red	#FF4040	100%	25%	25%	0°	100%	63%	75%	100%
Cordovan	#893F45	54%	25%	27%	337°	37%	39%	89%	94%
Corn	#FBEC5D	98%	93%	36%	54°	95%	68%	63%	98%
Cornell Red	#B31B1B	70%	11%	11%	0°	74%	40%	85%	70%
Cornflower blue	#6495ED	39%	58%	93%	219°	79%	66%	58%	93%
Cornsilk	#FFF8DC	100%	97%	86%	48°	100%	93%	14%	100%
Cosmic latte	#FFF8E7	100%	97%	91%	42°	100%	95%	9%	100%
Cotton candy	#FFBCD9	100%	74%	85%	334°	100%	87%	26%	100%
Cream	#FFFDD0	100%	99%	82%	57°	100%	91%	18%	100%
Crimson	#DC143C	86%	8%	24%	348°	83%	47%	91%	86%
Crimson glory	#BE0032	75%	0%	20%	356°	100%	37%	100%	75%
Cyan	#00FFFF	0%	100%	100%	180°	100%	50%	100%	100%
Cyan (process)	#00B7EB	0%	72%	92%	193°	100%	46%	100%	92%
Cyber grape	#58427C	35%	26%	49%	263°	31%	37%	47%	49%
Cyber yellow	#FFD300	100%	83%	0%	50°	100%	50%	100%	100%
Daffodil	#FFFF31	100%	100%	19%	60°	100%	60%	81%	100%
Dandelion	#F0E130	94%	88%	19%	55°	87%	57%	80%	94%
Dark blue	#00008B	0%	0%	55%	240°	100%	27%	100%	55%
Dark blue-gray	#666699	40%	40%	60%	240°	20%	50%	33%	60%
Dark brown	#654321	40%	26%	13%	30°	51%	26%	67%	40%
Dark byzantium	#5D3954	36%	22%	33%	315°	24%	29%	39%	37%
Dark candy apple red	#A40000	64%	0%	0%	0°	100%	32%	100%	64%
Dark cerulean	#08457E	3%	27%	49%	209°	88%	26%	94%	49%
Dark chestnut	#986960	60%	41%	38%	10°	23%	49%	37%	60%
Dark coral	#CD5B45	80%	36%	27%	10°	58%	54%	66%	80%
Dark cyan	#008B8B	0%	55%	55%	180°	100%	27%	24%	100%
Dark electric blue	#536878	33%	41%	47%	180°	18%	40%	20%	25%
Dark goldenrod	#B8860B	72%	53%	4%	43°	89%	38%	94%	72%
Dark gray	#A9A9A9	66%	66%	66%	—	0%	66%	0%	66%
Dark green	#013220	0%	20%	13%	158°	96%	10%	98%	20%
Dark imperial blue	#00416A	0%	25%	42%	203°	100%	21%	100%	42%
Dark jungle green	#1A2421	10%	14%	13%	120°	16%	12%	10%	10%
Dark khaki	#BDB76B	74%	72%	42%	56°	38%	58%	43%	74%
Dark lava	#483C32	28%	24%	20%	27°	18%	24%	31%	28%
Dark lavender	#734F96	45%	31%	59%	270°	31%	45%	47%	59%
Dark liver	#534B4F	33%	29%	31%	330°	5%	31%	10%	33%
Dark liver (horses)	#543D37	33%	24%	22%	12°	21%	27%	35%	33%
Dark magenta	#8B008B	55%	0%	55%	300°	100%	27%	100%	55%
Dark midnight blue	#003366	0%	20%	40%	210°	100%	20%	100%	40%
Dark moss green	#4A5D23	29%	36%	14%	80°	45%	25%	62%	37%
Dark olive green	#556B2F	33%	42%	18%	82°	39%	30%	56%	42%
Dark orange	#FF8C00	100%	55%	0%	34°	100%	50%	100%	94%
Dark orchid	#9932CC	60%	20%	80%	280°	61%	50%	75%	80%
Dark pastel blue	#779ECB	47%	62%	80%	212°	45%	63%	41%	80%
Dark pastel green	#03C03C	1%	75%	24%	138°	97%	38%	98%	75%
Dark pastel purple	#966FD6	59%	44%	84%	263°	56%	64%	48%	84%
Dark pastel red	#C23B22	76%	23%	13%	9°	70%	45%	82%	76%
Dark pink	#E75480	91%	33%	50%	342°	75%	62%	64%	91%
Dark powder blue	#003399	0%	20%	60%	220°	100%	30%	70%	60%
Dark raspberry	#872657	53%	15%	34%	330°	56%	34%	72%	53%
Dark red	#8B0000	55%	0%	0%	0°	100%	27%	100%	56%
Dark salmon	#E9967A	91%	59%	48%	15°	72%	70%	48%	91%
Dark scarlet	#560319	34%	1%	10%	344°	93%	18%	97%	34%
Dark sea green	#8FBC8F	56%	74%	56%	120°	25%	65%	24%	74%
Dark sienna	#3C1414	24%	8%	8%	0°	50%	16%	67%	24%
Dark sky blue	#8CBED6	55%	75%	84%	199°	47%	69%	35%	84%
Dark slate blue	#483D8B	28%	24%	55%	248°	39%	39%	56%	55%
Dark slate gray	#2F4F4F	18%	31%	31%	180°	25%	25%	41%	31%
Dark spring green	#177245	9%	45%	27%	150°	66%	27%	80%	45%
Dark tan	#918151	57%	51%	32%	45°	28%	44%	44%	57%
Dark tangerine	#FFA812	100%	66%	7%	38°	100%	54%	93%	100%
Dark taupe	#483C32	28%	24%	20%	30°	18%	24%	17%	34%
Dark terra cotta	#CC4E5C	80%	31%	36%	354°	55%	55%	55%	55%
Dark turquoise	#00CED1	0%	81%	82%	181°	100%	41%	100%	82%
Dark vanilla	#D1BEA8	82%	75%	66%	32°	31%	74%	20%	82%
Dark violet	#9400D3	58%	0%	83%	282°	100%	41%	100%	83%
Dark yellow	#9B870C	61%	53%	5%	295°	86%	33%	92%	61%
Dartmouth green	#00703C	0%	44%	24%	121°	100%	22%	90%	50%
Davy's grey	#555555	33%	33%	33%	—	0%	33%	0%	33%
Debian red	#D70A53	84%	4%	33%	339°	91%	44%	95%	84%
Deep carmine	#A9203E	66%	13%	24%	357°	68%	39%	100%	66%
Deep carmine pink	#EF3038	94%	19%	22%	357°	86%	56%	80%	94%
Deep carrot orange	#E9692C	91%	41%	17%	34°	81%	54%	76%	84%
Deep cerise	#DA3287	85%	20%	53%	330°	69%	53%	77%	85%
Deep champagne	#FAD6A5	98%	84%	65%	35°	90%	81%	34%	98%
Deep chestnut	#B94E48	73%	31%	28%	3°	45%	50%	61%	73%
Deep coffee	#704241	44%	26%	25%	1°	27%	35%	42%	44%
Deep fuchsia	#C154C1	76%	33%	76%	300°	47%	54%	56%	76%
Deep jungle green	#004B49	0%	29%	29%	120°	100%	15%	40%	40%
Deep lemon	#F5C71A	96%	78%	30%	47°	89%	63%	89%	96%
Deep lilac	#9955BB	60%	33%	73%	280°	43%	53%	55%	73%
Deep magenta	#CC00CC	80%	0%	80%	300°	100%	40%	100%	80%
Deep mauve	#D473D4	83%	45%	83%	300°	53%	64%	46%	83%
Deep moss green	#355E3B	21%	37%	23%	129°	28%	29%	44%	37%
Deep peach	#FFCBA4	100%	80%	64%	26°	100%	82%	36%	100%
Deep pink	#FF1493	100%	8%	58%	328°	100%	54%	92%	100%
Deep ruby	#843F5B	52%	25%	36%	336°	35%	38%	52%	52%
Deep saffron	#FF9933	100%	60%	20%	30°	100%	60%	80%	100%
Deep sky blue	#00BFFF	0%	75%	100%	195°	100%	50%	100%	100%
Deep Space Sparkle	#4A646C	29%	39%	42%	194°	19%	36%	32%	43%
Deep Taupe	#7E5E60	49%	37%	38%	356°	15%	43%	25%	49%
Deep Tuscan red	#66424D	40%	26%	30%	342°	21%	33%	35%	40%
Deer	#BA8759	73%	53%	35%	28°	41%	54%	52%	73%
Denim	#1560BD	8%	38%	74%	213°	80%	41%	89%	74%
Desert	#C19A6B	76%	60%	42%	33°	41%	59%	44%	76%
Desert sand	#EDC9AF	93%	79%	69%	25°	63%	81%	26%	93%
Diamond	#B9F2FF	73%	95%	100%	190°	100%	86%	100%	100%
Dim gray	#696969	41%	41%	41%	—	0%	41%	0%	41%
Dirt	#9B7653	61%	46%	33%	29°	30%	47%	47%	61%
Dodger blue	#1E90FF	12%	56%	100%	210°	100%	56%	88%	100%
Dogwood rose	#D71868	84%	9%	41%	330°	80%	47%	84%	82%
Dollar bill	#85BB65	52%	73%	40%	98°	39%	57%	46%	73%
Donkey Brown	#664C28	40%	30%	16%	35°	44%	28%	61%	40%
Drab	#967117	59%	44%	9%	43°	73%	34%	85%	59%
Duke blue	#00009C	0%	0%	61%	240°	100%	31%	100%	61%
Dust storm	#E5CCC9	90%	80%	79%	6°	35%	84%	12%	90%
Earth yellow	#E1A95F	88%	66%	37%	34°	68%	63%	58%	88%
Ebony	#555D50	33%	36%	31%	97°	8%	34%	14%	37%
Ecru	#C2B280	76%	70%	50%	45°	35%	63%	34%	76%
Eggplant	#614051	38%	25%	32%	329°	21%	32%	34%	38%
Eggshell	#F0EAD6	94%	92%	84%	46°	46%	89%	11%	94%
Egyptian blue	#1034A6	6%	20%	65%	226°	82%	36%	90%	65%
Electric blue	#7DF9FF	49%	98%	100%	183°	100%	75%	51%	100%
Electric crimson	#FF003F	100%	0%	25%	345°	100%	50%	100%	100%
Electric cyan	#00FFFF	0%	100%	100%	180°	100%	50%	100%	100%
Electric green	#00FF00	0%	100%	0%	120°	100%	50%	100%	100%
Electric indigo	#6F00FF	44%	0%	100%	266°	100%	50%	100%	100%
Electric lavender	#F4BBFF	96%	73%	100%	290°	100%	87%	27%	100%
Electric lime	#CCFF00	80%	100%	0%	72°	100%	50%	100%	100%
Electric purple	#BF00FF	75%	0%	100%	285°	100%	50%	100%	100%
Electric ultramarine	#3F00FF	25%	0%	100%	255°	100%	50%	100%	100%
Electric violet	#8F00FF	56%	0%	100%	274°	100%	50%	100%	100%
Electric yellow	#FFFF33	100%	100%	20%	60°	100%	60%	80%	100%
Emerald	#50C878	31%	78%	47%	140°	52%	55%	60%	78%
English green	#1B4D3E	11%	30%	24%	162°	48%	20%	65%	30%
English lavender	#B48395	71%	51%	58%	338°	25%	61%	27%	71%
English red	#AB4B52	67%	31%	32%	357°	37%	49%	54%	67%
English violet	#563C5C	34%	24%	36%	289°	21%	30%	35%	36%
Eton blue	#96C8A2	59%	78%	64%	134°	31%	69%	25%	78%
Eucalyptus	#44D7A8	27%	84%	66%	161°	65%	56%	68%	84%
Fallow	#C19A6B	76%	60%	42%	45°	41%	59%	17%	23%
Falu red	#801818	50%	9%	9%	0°	68%	30%	81%	50%
Fandango	#B53389	71%	20%	54%	320°	56%	46%	72%	71%
Fandango pink	#DE5285	87%	32%	52%	342°	68%	60%	63%	87%
Fashion fuchsia	#F400A1	96%	0%	63%	320°	100%	48%	100%	96%
Fawn	#E5AA70	90%	67%	44%	30°	69%	67%	51%	90%
Feldgrau	#4D5D53	30%	36%	33%	142°	9%	33%	17%	36%
Feldspar	#FDD5B1	88%	71%	51%	33°	60%	69%	60%	56%
Fern green	#4F7942	31%	47%	26%	106°	29%	37%	45%	47%
Ferrari Red	#FF2800	100%	16%	0%	9°	100%	50%	100%	100%
Field drab	#6C541E	42%	33%	12%	42°	57%	27%	72%	42%
Firebrick	#B22222	70%	13%	13%	0°	68%	42%	81%	70%
Fire engine red	#CE2029	81%	13%	16%	0°	73%	47%	92%	80%
Flame	#E25822	89%	35%	13%	17°	77%	51%	85%	89%
Flamingo pink	#FC8EAC	99%	56%	67%	344°	95%	77%	44%	99%
Flattery	#6B4423	40%	27%	14%	28°	49%	27%	67%	42%
Flavescent	#F7E98E	97%	91%	56%	52°	87%	76%	41%	76%
Flax	#EEDC82	93%	86%	51%	50°	76%	72%	45%	93%
Flirt	#A2006D	64%	0%	43%	320°	100%	32%	100%	64%
Floral white	#FFFAF0	100%	98%	94%	40°	100%	97%	6%	100%
Fluorescent orange	#FFBF00	100%	75%	0%	45°	100%	50%	100%	100%
Fluorescent pink	#FF1493	100%	8%	58%	328°	100%	54%	92%	100%
Fluorescent yellow	#CCFF00	80%	100%	0%	72°	100%	50%	100%	100%
Folly	#FF004F	100%	0%	31%	341°	100%	50%	100%	100%
Forest green (traditional)	#014421	0%	27%	13%	149°	97%	14%	99%	27%
Forest green (web)	#228B22	13%	55%	13%	120°	61%	34%	76%	55%
French beige	#A67B5B	65%	48%	36%	26°	30%	50%	45%	65%
French bistre	#856D4D	52%	43%	30%	34°	27%	41%	42%	52%
French blue	#0072BB	0%	45%	73%	203°	100%	37%	100%	73%
French lilac	#86608E	53%	38%	56%	290°	19%	47%	32%	56%
French lime	#9EFD38	62%	99%	22%	89°	98%	61%	78%	99%
French mauve	#D473D4	83%	45%	83%	300°	53%	64%	46%	83%
French raspberry	#C72C48	78%	17%	28%	351°	64%	48%	78%	78%
French rose	#F64A8A	96%	29%	54%	338°	91%	63%	70%	96%
French sky blue	#77B5FE	47%	71%	100%	213°	99%	73%	53%	100%
French wine	#AC1E44	67%	12%	27%	344°	70%	40%	83%	68%
Fresh Air	#A6E7FF	65%	91%	100%	196°	100%	83%	35%	100%
Fuchsia	#FF00FF	100%	0%	100%	321°	100%	50%	100%	100%
Fuchsia (Crayola)	#C154C1	76%	33%	76%	300°	47%	54%	56%	76%
Fuchsia pink	#FF77FF	100%	47%	100%	313°	100%	73%	53%	100%
Fuchsia rose	#C74375	78%	26%	46%	337°	54%	52%	66%	78%
Fulvous	#E48400	89%	52%	0%	35°	100%	45%	100%	89%
Fuzzy Wuzzy	#CC6666	80%	40%	40%	0°	50%	60%	50%	80%
Gainsboro	#DCDCDC	86%	86%	86%	—	0%	86%	0%	86%
Gamboge	#E49B0F	89%	61%	6%	38°	88%	48%	94%	94%
Ghost white	#F8F8FF	97%	97%	100%	24°	100%	99%	3%	100%
Giants orange	#FE5A1D	100%	35%	11%	16°	99%	56%	89%	100%
Ginger	#B06500	69%	40%	0%	24°	100%	35%	100%	69%
Glaucous	#6082B6	38%	51%	71%	216°	37%	55%	47%	71%
Glitter	#E6E8FA	90%	91%	98%	234°	67%	94%	8%	98%
GO green	#00AB66	0%	67%	40%	156°	100%	34%	100%	75%
Gold (metallic)	#D4AF37	83%	69%	22%	46°	65%	52%	74%	83%
Gold (web) (Golden)	#FFD700	100%	84%	0%	51°	100%	50%	100%	100%
Gold Fusion	#85754E	52%	46%	31%	43°	26%	41%	41%	52%
Golden brown	#996515	60%	40%	8%	36°	76%	34%	83%	60%
Golden poppy	#FCC200	99%	76%	0%	46°	100%	49%	100%	99%
Golden yellow	#FFDF00	100%	87%	0%	52°	100%	50%	100%	100%
Goldenrod	#DAA520	85%	65%	13%	43°	74%	49%	85%	85%
Granny Smith Apple	#A8E4A0	66%	89%	63%	113°	56%	76%	30%	89%
Grape	#6F2DA8	42%	18%	66%	270°	58%	42%	73%	66%
Gray	#808080	50%	50%	50%	—	0%	50%	0%	50%
Gray (HTML/CSS gray)	#808080	50%	50%	50%	—	0%	50%	0%	50%
Gray (X11 gray)	#BEBEBE	75%	75%	75%	—	0%	75%	0%	75%
Gray-asparagus	#465945	27%	35%	27%	117°	13%	31%	22%	35%
Gray-blue	#8C92AC	55%	57%	67%	229°	16%	61%	19%	68%
Green (color wheel) (X11 green)	#00FF00	0%	100%	0%	120°	100%	50%	100%	100%
Green (Crayola)	#1CAC78	11%	67%	47%	159°	72%	39%	72%	78%
Green (HTML/CSS color)	#008000	0%	50%	0%	120°	100%	25%	100%	50%
Green (Munsell)	#00A877	0%	66%	47%	163°	100%	33%	100%	66%
Green (NCS)	#009F6B	0%	62%	42%	160°	100%	31%	100%	62%
Green (pigment)	#00A550	0%	65%	31%	149°	100%	32%	100%	65%
Green (RYB)	#66B032	40%	69%	20%	95°	56%	44%	72%	69%
Green-yellow	#ADFF2F	68%	100%	18%	84°	100%	59%	82%	100%
Grullo	#A99A86	66%	60%	53%	34°	17%	59%	21%	66%
Guppie green	#00FF7F	0%	100%	50%	150°	100%	50%	100%	100%
Halayà úbe	#663854	40%	22%	33%	278°	30%	31%	12%	37%
Han blue	#446CCF	27%	42%	81%	223°	59%	54%	67%	81%
Han purple	#5218FA	32%	9%	98%	255°	96%	54%	90%	98%
Hansa yellow	#E9D66B	91%	84%	42%	51°	74%	67%	54%	91%
Harlequin	#3FFF00	25%	100%	0%	105°	100%	50%	100%	100%
Harvard crimson	#C90016	79%	0%	9%	353°	100%	39%	100%	79%
Harvest gold	#DA9100	85%	57%	0%	40°	100%	43%	100%	86%
Heart Gold	#808000	50%	50%	0%	43°	100%	25%	100%	25%
Heliotrope	#DF73FF	87%	45%	100%	286°	100%	73%	55%	100%
Hollywood cerise	#F400A1	96%	0%	63%	320°	100%	48%	100%	96%
Honeydew	#F0FFF0	94%	100%	94%	150°	100%	97%	97%	97%
Honolulu blue	#006DB0	0%	43%	69%	203°	100%	35%	100%	69%
Hooker's green	#49796B	29%	47%	42%	163°	25%	38%	40%	48%
Hot magenta	#FF1DCE	100%	11%	81%	313°	100%	56%	89%	100%
Hot pink	#FF69B4	100%	41%	71%	330°	100%	71%	59%	100%
Hunter green	#355E3B	21%	37%	23%	129°	28%	29%	44%	37%
Iceberg	#71A6D2	44%	65%	82%	207°	52%	63%	46%	82%
Icterine	#FCF75E	99%	97%	37%	58°	96%	68%	63%	99%
Illuminating Emerald	#319177	19%	57%	47%	164°	50%	38%	66%	57%
Imperial	#602F6B	38%	18%	42%	289°	39%	30%	56%	42%
Imperial blue	#002395	0%	14%	58%	226°	100%	29%	100%	58%
Imperial purple	#66023C	40%	1%	24%	325°	96%	20%	98%	40%
Imperial red	#ED2939	93%	16%	22%	355°	85%	55%	83%	93%
Inchworm	#B2EC5D	70%	93%	36%	84°	79%	65%	61%	93%
India green	#138808	7%	53%	3%	115°	89%	28%	94%	53%
Indian red	#CD5C5C	80%	36%	36%	0°	53%	58%	52%	75%
Indian yellow	#E3A857	89%	66%	34%	35°	71%	62%	62%	89%
Indigo	#6F00FF	44%	0%	100%	266°	100%	50%	100%	100%
Indigo (dye)	#00416A	0%	25%	42%	203°	100%	21%	100%	42%
Indigo (web)	#4B0082	29%	0%	51%	275°	100%	26%	100%	50%
International Klein Blue	#002FA7	0%	18%	65%	223°	100%	33%	100%	65%
International orange (aerospace)	#FF4F00	100%	31%	0%	19°	100%	50%	100%	100%
International orange (engineering)	#BA160C	73%	9%	5%	3°	88%	39%	94%	73%
International orange (Golden Gate Bridge)	#C0362C	75%	21%	17%	4°	63%	46%	77%	75%
Iris	#5A4FCF	35%	31%	81%	245°	57%	56%	62%	81%
Irresistible	#B3446C	70%	27%	42%	338°	45%	48%	62%	70%
Isabelline	#F4F0EC	96%	94%	93%	30°	27%	94%	3%	96%
Islamic green	#009000	0%	56%	0%	120°	100%	28%	100%	56%
Italian sky blue	#B2FFFF	70%	100%	100%	180°	100%	85%	30%	100%
Ivory	#FFFFF0	100%	100%	94%	60°	100%	97%	6%	100%
Jade	#00A86B	0%	66%	42%	158°	100%	33%	100%	66%
Japanese indigo	#264348	15%	26%	28%	189°	31%	22%	47%	28%
Japanese violet	#5B3256	36%	20%	34%	307°	29%	28%	45%	36%
Jasmine	#F8DE7E	97%	87%	49%	47°	90%	73%	49%	97%
Jasper	#D73B3E	84%	23%	24%	359°	66%	54%	73%	84%
Jazzberry jam	#A50B5E	65%	4%	37%	322°	88%	35%	90%	47%
Jelly Bean	#DA614E	85%	38%	31%	8°	65%	58%	64%	86%
Jet	#343434	20%	20%	20%	—	0%	20%	0%	20%
Jonquil	#F4CA16	96%	79%	9%	49°	91%	52%	91%	96%
June bud	#BDDA57	74%	85%	34%	80°	64%	60%	75%	85%
Jungle green	#29AB87	16%	67%	53%	163°	61%	42%	76%	67%
Kelly green	#4CBB17	30%	73%	9%	101°	78%	41%	88%	73%
Kenyan copper	#7C1C05	49%	11%	2%	12°	92%	25%	96%	49%
Keppel	#3AB09E	23%	69%	62%	171°	50%	46%	67%	69%
Khaki (HTML/CSS) (Khaki)	#C3B091	76%	69%	57%	37°	29%	67%	26%	76%
Khaki (X11) (Light khaki)	#F0E68C	94%	90%	55%	54°	77%	75%	42%	94%
Kobe	#882D17	53%	18%	9%	12°	71%	31%	83%	53%
Kobi	#E79FC4	91%	62%	77%	329°	60%	77%	31%	91%
KU Crimson	#E8000D	91%	0%	5%	357°	100%	46%	100%	91%
La Salle Green	#087830	3%	47%	19%	141°	88%	25%	93%	47%
Languid lavender	#D6CADD	84%	79%	87%	270°	22%	83%	17%	82%
Lapis lazuli	#26619C	15%	38%	61%	210°	61%	38%	76%	61%
Laser Lemon	#FFFF66	100%	100%	40%	60°	100%	70%	60%	100%
Laurel green	#A9BA9D	66%	73%	62%	95°	17%	67%	16%	73%
Lava	#CF1020	81%	6%	13%	355°	86%	44%	92%	81%
Lavender (floral)	#B57EDC	71%	49%	86%	275°	57%	68%	43%	86%
Lavender (web)	#E6E6FA	90%	90%	98%	245°	67%	94%	8%	98%
Lavender blue	#CCCCFF	80%	80%	100%	240°	100%	90%	20%	100%
Lavender blush	#FFF0F5	100%	94%	96%	340°	100%	97%	6%	100%
Lavender gray	#C4C3D0	77%	76%	82%	245°	12%	79%	6%	82%
Lavender indigo	#9457EB	58%	34%	92%	265°	79%	63%	63%	92%
Lavender magenta	#EE82EE	93%	51%	93%	300°	76%	72%	45%	93%
Lavender mist	#E6E6FA	90%	90%	98%	240°	67%	94%	8%	98%
Lavender pink	#FBAED2	98%	68%	82%	332°	91%	83%	31%	98%
Lavender purple	#967BB6	59%	48%	71%	267°	29%	60%	32%	71%
Lavender rose	#FBA0E3	98%	63%	89%	316°	92%	81%	36%	98%
Lawn green	#7CFC00	49%	99%	0%	90°	100%	49%	98%	48%
Lemon	#FFF700	100%	97%	0%	58°	100%	50%	100%	100%
Lemon chiffon	#FFFACD	100%	98%	80%	54°	100%	90%	20%	100%
Lemon curry	#CCA01D	80%	63%	11%	45°	75%	46%	86%	80%
Lemon glacier	#FDFF00	99%	100%	0%	60°	100%	50%	100%	100%
Lemon lime	#E3FF00	89%	100%	0%	44°	100%	50%	100%	100%
Lemon meringue	#F6EABE	96%	92%	75%	47°	76%	86%	23%	97%
Lemon yellow	#FFF44F	100%	96%	31%	56°	100%	66%	69%	100%
Licorice	#1A1110	10%	7%	6%	6°	24%	8%	39%	10%
Light apricot	#FDD5B1	99%	84%	69%	30°	95%	84%	22%	89%
Light blue	#ADD8E6	68%	85%	90%	194°	53%	79%	24%	90%
Light brown	#B5651D	71%	40%	11%	28°	72%	41%	84%	71%
Light carmine pink	#E66771	90%	40%	44%	350°	72%	65%	70%	80%
Light coral	#F08080	94%	50%	50%	0°	79%	72%	50%	100%
Light cornflower blue	#93CCEA	58%	80%	92%	201°	67%	75%	37%	92%
Light crimson	#F56991	96%	41%	57%	343°	88%	69%	57%	96%
Light cyan	#E0FFFF	88%	100%	100%	180°	100%	94%	12%	100%
Light fuchsia pink	#F984EF	98%	52%	94%	300°	91%	75%	27%	94%
Light goldenrod yellow	#FAFAD2	98%	98%	82%	60°	80%	90%	16%	98%
Light gray	#D3D3D3	83%	83%	83%	—	0%	83%	0%	83%
Light green	#90EE90	56%	93%	56%	120°	73%	75%	39%	93%
Light khaki	#F0E68C	94%	90%	55%	54°	77%	75%	42%	94%
Light medium orchid	#D39BCB	83%	61%	80%	309°	39%	72%	27%	83%
Light moss green	#ADDFAD	68%	78%	68%	135°	20%	73%	20%	87%
Light orchid	#E6A8D7	90%	66%	84%	315°	55%	78%	27%	90%
Light pastel purple	#B19CD9	69%	61%	85%	261°	45%	73%	28%	85%
Light pink	#FFB6C1	100%	71%	76%	351°	100%	86%	100%	86%
Light red ochre	#E97451	91%	45%	32%	14°	78%	62%	65%	91%
Light salmon	#FFA07A	100%	63%	48%	14°	100%	74%	62%	100%
Light salmon pink	#FF9999	100%	60%	60%	0°	100%	80%	40%	100%
Light sea green	#20B2AA	13%	70%	67%	175°	70%	41%	40%	75%
Light sky blue	#87CEFA	53%	81%	98%	203°	92%	76%	46%	98%
Light slate gray	#778899	47%	53%	60%	210°	14%	53%	22%	60%
Light steel blue	#B0C4DE	69%	77%	87%	214°	41%	78%	21%	87%
Light taupe	#B38B6D	70%	55%	43%	26°	32%	57%	39%	70%
Light Thulian pink	#E68FAC	90%	56%	67%	330°	64%	73%	72%	94%
Light yellow	#FFFFE0	100%	100%	88%	60°	100%	94%	7%	100%
Lilac	#C8A2C8	78%	64%	78%	300°	26%	71%	19%	78%
Lime (color wheel)	#BFFF00	75%	100%	0%	75°	100%	50%	100%	100%
Lime (web) (X11 green)	#00FF00	0%	100%	0%	120°	100%	50%	100%	100%
Lime green	#32CD32	20%	80%	20%	120°	61%	50%	67%	40%
Limerick	#9DC209	62%	76%	4%	72°	91%	40%	95%	76%
Lincoln green	#195905	10%	35%	2%	106°	89%	18%	94%	35%
Linen	#FAF0E6	98%	94%	90%	30°	67%	94%	8%	98%
Lion	#C19A6B	76%	60%	42%	33°	41%	59%	45%	76%
Little boy blue	#6CA0DC	42%	63%	86%	212°	62%	64%	51%	86%
Liver	#674C47	40%	30%	28%	9°	18%	34%	31%	30%
Liver (dogs)	#B86D29	72%	43%	16%	28°	64%	44%	77%	72%
Liver (organ)	#6C2E1F	42%	18%	12%	12°	55%	27%	71%	42%
Liver chestnut	#987456	60%	45%	34%	27°	28%	47%	43%	60%
Lumber	#FFE4CD	100%	89%	80%	8°	100%	90%	20%	100%
Lust	#E62020	90%	13%	13%	0°	80%	51%	86%	90%
Magenta	#FF00FF	100%	0%	100%	300°	100%	50%	100%	100%
Magenta (Crayola)	#FF55A3	100%	33%	64%	332°	100%	67%	67%	100%
Magenta (dye)	#CA1F7B	79%	12%	48%	326°	73%	46%	90%	79%
Magenta (Pantone)	#D0417E	82%	25%	49%	334°	60%	54%	69%	82%
Magenta (process)	#FF0090	100%	0%	56%	326°	100%	50%	100%	100%
Magic mint	#AAF0D1	67%	94%	82%	150°	70%	80%	84%	80%
Magnolia	#F8F4FF	97%	96%	100%	247°	100%	98%	94%	92%
Mahogany	#C04000	75%	25%	0%	20°	100%	38%	100%	75%
Maize	#FBEC5D	98%	93%	36%	54°	95%	68%	63%	98%
Majorelle Blue	#6050DC	38%	31%	86%	247°	67%	59%	67%	59%
Malachite	#0BDA51	4%	85%	32%	140°	90%	45%	95%	85%
Manatee	#979AAA	59%	60%	67%	231°	10%	63%	11%	67%
Mango Tango	#FF8243	100%	51%	26%	20°	100%	63%	74%	100%
Mantis	#74C365	45%	76%	40%	110°	44%	58%	48%	77%
Mardi Gras	#880085	53%	0%	54%	301°	100%	27%	100%	53%
Maroon (Crayola)	#C32148	76%	13%	28%	345°	71%	45%	75%	38%
Maroon (HTML/CSS)	#800000	50%	0%	0%	0°	100%	25%	100%	50%
Maroon (X11)	#B03060	69%	19%	38%	333°	57%	44%	65%	42%
Mauve	#E0B0FF	88%	69%	100%	276°	100%	85%	31%	100%
Mauve taupe	#915F6D	57%	37%	43%	285°	21%	47%	37%	54%
Mauvelous	#EF98AA	94%	60%	67%	348°	73%	77%	37%	94%
Maya blue	#73C2FB	45%	76%	98%	210°	94%	72%	96%	87%
Meat brown	#E5B73B	90%	72%	23%	44°	77%	57%	74%	90%
Medium aquamarine	#66DDAA	40%	87%	67%	154°	64%	63%	54%	87%
Medium blue	#0000CD	0%	0%	80%	240°	100%	40%	100%	80%
Medium candy apple red	#E2062C	89%	2%	17%	350°	95%	46%	97%	89%
Medium carmine	#AF4035	69%	25%	21%	5°	54%	45%	69%	68%
Medium champagne	#F3E5AB	95%	90%	67%	48°	75%	81%	30%	95%
Medium electric blue	#035096	1%	31%	59%	180°	96%	30%	30%	60%
Medium jungle green	#1C352D	11%	21%	18%	120°	31%	16%	20%	20%
Medium lavender magenta	#DDA0DD	87%	63%	87%	200°	47%	75%	28%	87%
Medium orchid	#BA55D3	73%	33%	83%	288°	59%	58%	60%	83%
Medium Persian blue	#0067A5	0%	40%	65%	248°	100%	32%	75%	48%
Medium purple	#9370DB	58%	44%	86%	270°	60%	65%	68%	72%
Medium red-violet	#BB3385	73%	20%	52%	322°	57%	47%	79%	83%
Medium ruby	#AA4069	67%	25%	41%	337°	45%	46%	62%	67%
Medium sea green	#3CB371	24%	70%	44%	150°	50%	47%	42%	30%
Medium sky blue	#80DAEB	50%	85%	92%	190°	73%	71%	46%	92%
Medium slate blue	#7B68EE	48%	41%	93%	249°	80%	67%	56%	93%
Medium spring bud	#C9DC87	79%	86%	53%	80°	55%	70%	70%	80%
Medium spring green	#00FA9A	0%	98%	60%	150°	100%	49%	97%	97%
Medium taupe	#674C47	40%	30%	28%	9°	18%	34%	31%	40%
Medium turquoise	#48D1CC	28%	82%	80%	175°	60%	55%	55%	50%
Medium Tuscan red	#79443B	47%	27%	23%	9°	34%	35%	51%	53%
Medium vermilion	#D9603B	85%	38%	23%	14°	68%	54%	73%	85%
Medium violet-red	#C71585	78%	8%	52%	322°	81%	43%	89%	78%
Mellow apricot	#F8B878	97%	72%	47%	30°	90%	72%	52%	97%
Mellow yellow	#F8DE7E	97%	87%	49%	47°	90%	73%	49%	97%
Melon	#FDBCB4	99%	74%	71%	7°	95%	85%	29%	99%
Metallic Seaweed	#0A7E8C	3%	49%	55%	186°	89%	29%	94%	55%
Metallic Sunburst	#9C7C38	61%	49%	22%	41°	47%	42%	64%	61%
Mexican pink	#E4007C	89%	0%	49%	327°	100%	45%	100%	89%
Midnight blue	#191970	10%	10%	44%	240°	64%	27%	78%	44%
Midnight green (eagle green)	#004953	0%	29%	33%	187°	100%	16%	100%	33%
Midori	#E3F988	89%	98%	53%	72°	90%	76%	45%	98%
Mikado yellow	#FFC40C	100%	77%	5%	45°	100%	52%	95%	100%
Mint	#3EB489	24%	71%	54%	158°	49%	48%	66%	71%
Mint cream	#F5FFFA	96%	100%	98%	150°	100%	98%	4%	100%
Mint green	#98FF98	60%	100%	60%	140°	100%	80%	40%	100%
Misty rose	#FFE4E1	100%	89%	88%	6°	100%	94%	12%	100%
Moccasin	#FAEBD7	98%	92%	84%	34°	78%	91%	14%	98%
Mode beige	#967117	59%	44%	9%	43°	73%	34%	85%	59%
Moonstone blue	#73A9C2	45%	66%	76%	199°	39%	61%	41%	76%
Mordant red 19	#AE0C00	68%	5%	0%	4°	100%	34%	100%	68%
Moss green	#8A9A5B	54%	60%	36%	75°	26%	48%	41%	60%
Mountain Meadow	#30BA8F	19%	73%	56%	161°	59%	46%	74%	73%
Mountbatten pink	#997A8D	60%	48%	55%	323°	13%	54%	20%	60%
MSU Green	#18453B	9%	27%	23%	167°	48%	18%	65%	27%
Mughal green	#306030	19%	38%	19%	120°	33%	28%	50%	38%
Mulberry	#C54B8C	77%	29%	55%	285°	51%	53%	67%	70%
Mustard	#FFDB58	100%	86%	35%	47°	100%	67%	65%	100%
Myrtle green	#317873	19%	47%	45%	176°	42%	33%	59%	47%"""


fields = [line.split("\t") for line in color_table.split("\n")]

color_names = [field[0].lower() for field in fields]
hex_codes = [field[1] for field in fields]

rgb = dict(zip(color_names, hex_codes))
